@@ -174,19 +174,14 @@ def load_module_from_file_object(
         try:
             # print version
             ts = fp.read(4)
-            try:
-                import importlib
-                my_magic_int = magics.magic2int(importlib.util.MAGIC_NUMBER)
-            except:
-                import imp
-                my_magic_int = magics.magic2int(imp.get_magic())
+            my_magic_int = magics.PYTHON_MAGIC_INT
             magic_int = magics.magic2int(magic)
 
             if magic_int == 3393:
                 timestamp = 0
                 _ = unpack("<I", ts)[0]  # hash word 1
                 _ = unpack("<I", fp.read(4))[0]  # hash word 2
-            elif magic_int in (3394, 3401, 3412):
+            elif magic_int in (3394, 3401, 3412, 3413):
                 timestamp = 0
                 _ = unpack("<I", fp.read(4))[0]  # pep552_bits
             else:
