@@ -46,6 +46,7 @@ from xdis.opcodes import opcode_38 as opcode_38
 from xdis.opcodes import opcode_26pypy as opcode_26pypy
 from xdis.opcodes import opcode_27pypy as opcode_27pypy
 from xdis.opcodes import opcode_32pypy as opcode_32pypy
+from xdis.opcodes import opcode_33pypy as opcode_33pypy
 from xdis.opcodes import opcode_35pypy as opcode_35pypy
 from xdis.opcodes import opcode_36pypy as opcode_36pypy
 
@@ -120,6 +121,7 @@ op_imports = {
     '2.6pypy':  opcode_26pypy,
     '2.7pypy':  opcode_27pypy,
     '3.2pypy':  opcode_32pypy,
+    '3.3pypy':  opcode_33pypy,
     '3.5pypy':  opcode_35pypy,
     '3.6pypy':  opcode_36pypy,
     '3.6.1pypy':  opcode_36pypy,
