@@ -49,38 +49,11 @@ def_op(l, 'ROT_FOUR',           6,   4, 4)
 def_op(l, 'BEGIN_FINALLY',     53,   0, 1)
 def_op(l, 'END_ASYNC_FOR',     54,   7, 0)  # POP is 0, when not 7
 def_op(l, 'END_FINALLY',       88,   1, 0)  # POP is 6, when not 1
-jrel_op(l, 'CALL_FINALLY',     162,   0, 1)
+jrel_op(l, 'CALL_FINALLY',    162,   0, 1)
 nargs_op(l, 'POP_FINALLY',    163,   0, 0)  # PUSH/POP vary
 
-MAKE_FUNCTION_FLAGS = tuple("default keyword-only annotation closure".split())
-
-def format_MAKE_FUNCTION_arg(flags):
-    pattr = ''
-    for flag in MAKE_FUNCTION_FLAGS:
-        bit = flags & 1
-        if bit:
-            if pattr:
-                pattr += ", " + flag
-            else:
-                pattr = flag
-                pass
-            pass
-        flags >>= 1
-    return pattr
-
-def format_value_flags(flags):
-    if (flags & 0x03) == 0x00:
-        return ''
-    elif (flags & 0x03) == 0x01:
-        return '!s'
-    elif (flags & 0x03) == 0x02:
-        return '!r'
-    elif (flags & 0x03) == 0x03:
-        return '!a'
-    elif (flags & 0x04) == 0x04:
-        # pop fmt_spec from the stack and use it, else use an
-        # empty fmt_spec.
-        return ''
+format_MAKE_FUNCTION_arg = opcode_37.format_MAKE_FUNCTION_arg
+format_value_flags = opcode_37.format_value_flags
 
 opcode_arg_fmt = {
     'MAKE_FUNCTION': format_MAKE_FUNCTION_arg,
