@@ -47,13 +47,7 @@ else:
 
 
 def compat_str(s):
-    if (
-        PYTHON_VERSION > 3.2
-        or
-        # FIXME: investigate
-        PYTHON_VERSION == 3.2
-        and IS_PYPY
-    ):
+    if PYTHON3:
         try:
             return s.decode("utf-8")
         except UnicodeDecodeError:
@@ -61,7 +55,6 @@ def compat_str(s):
             # and it will get converted to str when needed
             return s
 
-    elif PYTHON3:
         return s.decode()
     else:
         return str(s)
@@ -122,6 +115,7 @@ def load_code(fp, magic_int, code_objects={}):
 def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     # FIXME: use tables to simplify this?
     # Python [1.0 .. 2.2)
+
     v10_to_12 = magic_int in (39170, 39171)
 
     # FIXME: find out what magics were for 1.3
@@ -145,7 +139,7 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     else:
         co_posonlyargcount = None
 
-    if ((3020 < magic_int < 20121) or magic_int in (160,)) and not v11_to_14:
+    if ((3020 < magic_int < 20121) or magic_int in (64, 160, 112, 192)) and not v11_to_14:
         kwonlyargcount = unpack("<i", fp.read(4))[0]
     else:
         kwonlyargcount = 0
@@ -214,7 +208,7 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     # bytes (which is probably more logical).
     if PYTHON3:
         Code = types.CodeType
-        if PYTHON_MAGIC_INT > 3020:
+        if PYTHON_MAGIC_INT > 3020 or PYTHON_MAGIC_INT in IS_PYPY3:
             # Check for Python 3 interpreter reading Python 2 bytecode.
             # Python 3's code objects are bytes while Python 2's are strings.
             #
@@ -397,7 +391,7 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
                     co_cellvars,
                 )
             else:
-                if magic_int in (160,):
+                if magic_int in (160, 192):
                     co_filename = str(co_filename)
                     co_name = str(co_name)
                     co_varnames = tuple([str(t) for t in co_varnames])
